@@ -1,16 +1,24 @@
+import builtins
 import sys
 import threading
+import warnings
 
+from datetime import datetime, timezone
 from functools import wraps
-from typing import Union, Tuple, Callable, Optional, List, Type
+from typing import Union, Tuple, Callable, Optional, List, Type, Dict, Any
 
+from bugsnag.breadcrumbs import (
+    Breadcrumb,
+    BreadcrumbType,
+    OnBreadcrumbCallback
+)
 from bugsnag.configuration import Configuration, RequestConfiguration
 from bugsnag.event import Event
+from bugsnag.feature_flags import FeatureFlag
 from bugsnag.handlers import BugsnagHandler
 from bugsnag.sessiontracker import SessionTracker
-
-import bugsnag
-
+from bugsnag.utils import to_rfc3339
+from bugsnag.context import ContextLocalState
 
 __all__ = ('Client',)
 
@@ -27,6 +35,7 @@ class Client:
         self.configuration = configuration or Configuration()  # type: Configuration  # noqa: E501
         self.session_tracker = SessionTracker(self.configuration)
         self.configuration.configure(**kwargs)
+        self._context = ContextLocalState(self)
 
         if install_sys_hook:
             self.install_sys_hook()
@@ -72,8 +81,15 @@ class Client:
         >>> client.notify(Exception('Example'))  # doctest: +SKIP
         """
 
-        event = Event(exception, self.configuration,
-                      RequestConfiguration.get_instance(), **options)
+        event = Event(
+            exception,
+            self.configuration,
+            RequestConfiguration.get_instance(),
+            **options,
+            feature_flag_delegate=self._context.feature_flag_delegate
+        )
+
+        self._leave_breadcrumb_for_event(event)
         self.deliver(event, asynchronous=asynchronous)
 
     def notify_exc_info(self, exc_type, exc_value, traceback,
@@ -86,8 +102,15 @@ class Client:
 
         exception = exc_value
         options['traceback'] = traceback
-        event = Event(exception, self.configuration,
-                      RequestConfiguration.get_instance(), **options)
+        event = Event(
+            exception,
+            self.configuration,
+            RequestConfiguration.get_instance(),
+            **options,
+            feature_flag_delegate=self._context.feature_flag_delegate
+        )
+
+        self._leave_breadcrumb_for_event(event)
         self.deliver(event, asynchronous=asynchronous)
 
     def excepthook(self, exc_type, exc_value, traceback):
@@ -157,9 +180,12 @@ class Client:
                     options = {'asynchronous': asynchronous}
 
                 if event.api_key is None:
-                    bugsnag.logger.warning(
-                        "No API key configured, couldn't notify")
+                    self.configuration.logger.warning(
+                        "No API key configured, couldn't notify"
+                    )
+
                     return
+
                 if initial_severity != event.severity:
                     event.severity_reason = {
                         'type': 'userCallbackSetSeverity'
@@ -171,7 +197,11 @@ class Client:
                     self.configuration.delivery.deliver(self.configuration,
                                                         payload, options)
                 except Exception as e:
-                    bugsnag.logger.exception('Notifying Bugsnag failed %s', e)
+                    self.configuration.logger.exception(
+                        'Notifying Bugsnag failed %s',
+                        e
+                    )
+
                 # Trigger session delivery
                 self.session_tracker.send_sessions()
 
@@ -184,15 +214,117 @@ class Client:
         if not self.configuration.should_notify():
             return False
 
-        # Return early if we should ignore exceptions of this type
-        if self.configuration.should_ignore(event.exception):
+        # Return early if we should ignore these errors
+        if self.configuration.should_ignore(event.errors):
             return False
 
         return True
 
-    def log_handler(self, extra_fields: List[str] = None) -> BugsnagHandler:
+    def log_handler(
+        self,
+        extra_fields: Optional[List[str]] = None
+    ) -> BugsnagHandler:
         return BugsnagHandler(client=self, extra_fields=extra_fields)
 
+    @property
+    def feature_flags(self) -> List[FeatureFlag]:
+        return self._context.feature_flag_delegate.to_list()
+
+    def add_feature_flag(
+        self,
+        name: Union[str, bytes],
+        variant: Union[None, str, bytes] = None
+    ) -> None:
+        self._context.feature_flag_delegate.add(name, variant)
+
+    def add_feature_flags(self, feature_flags: List[FeatureFlag]) -> None:
+        self._context.feature_flag_delegate.merge(feature_flags)
+
+    def clear_feature_flag(self, name: Union[str, bytes]) -> None:
+        self._context.feature_flag_delegate.remove(name)
+
+    def clear_feature_flags(self) -> None:
+        self._context.feature_flag_delegate.clear()
+
+    @property
+    def breadcrumbs(self) -> List[Breadcrumb]:
+        return self.configuration.breadcrumbs
+
+    def add_on_breadcrumb(self, on_breadcrumb: OnBreadcrumbCallback) -> None:
+        self.configuration.add_on_breadcrumb(on_breadcrumb)
+
+    def remove_on_breadcrumb(
+        self,
+        on_breadcrumb: OnBreadcrumbCallback
+    ) -> None:
+        self.configuration.remove_on_breadcrumb(on_breadcrumb)
+
+    def leave_breadcrumb(
+        self,
+        message: str,
+        metadata: Dict[str, Any] = {},
+        type: BreadcrumbType = BreadcrumbType.MANUAL
+    ) -> None:
+        # Don't create breadcrumbs if the max_breadcrumbs is 0 as they would
+        # be immediately discarded anyway
+        if self.configuration.max_breadcrumbs == 0:
+            return
+
+        if not isinstance(type, BreadcrumbType):
+            type = BreadcrumbType.MANUAL
+
+        if not isinstance(metadata, dict):
+            warning_message = 'breadcrumb metadata must be a dict, got {}'
+            warnings.warn(
+                warning_message.format(builtins.type(metadata).__name__),
+                RuntimeWarning
+            )
+
+            metadata = {}
+
+        timestamp = to_rfc3339(datetime.now(timezone.utc))
+        breadcrumb = Breadcrumb(message, type, metadata, timestamp)
+
+        for callback in self.configuration._on_breadcrumbs:
+            try:
+                should_continue = callback(breadcrumb)
+
+                if should_continue is False:
+                    self.configuration.logger.info(
+                        'Breadcrumb not attached due to on_breadcrumb callback'
+                    )
+
+                    return
+            except Exception:
+                self.configuration.logger.exception(
+                    'Exception raised in on_breadcrumb callback'
+                )
+
+        self.configuration._breadcrumbs.append(breadcrumb)
+
+    def _auto_leave_breadcrumb(
+        self,
+        message: str,
+        metadata: Dict[str, Any],
+        type: BreadcrumbType
+    ) -> None:
+        if type in self.configuration.enabled_breadcrumb_types:
+            self.leave_breadcrumb(message, metadata, type)
+
+    def _leave_breadcrumb_for_event(self, event: Event) -> None:
+        error_class = event.errors[0].error_class
+
+        self._auto_leave_breadcrumb(
+            error_class,
+            {
+                'errorClass': error_class,
+                'message': event.errors[0].error_message,
+                'unhandled': event.unhandled,
+                'severity': event.severity,
+            },
+            BreadcrumbType.ERROR
+        )
+
 
 class ClientContext:
     def __init__(self, client,
