@@ -12,7 +12,6 @@ from urllib.request import (
     build_opener
 )
 
-import bugsnag
 from bugsnag.event import Event
 
 try:
@@ -56,13 +55,13 @@ class Delivery:
     def __init__(self):
         self.sent_session_warning = False
 
-    def deliver(self, config, payload: Any, options={}):
+    def deliver(self, config, payload: Any, options=None):
         """
         Sends error reports to Bugsnag
         """
         pass
 
-    def deliver_sessions(self, config, payload: Any):
+    def deliver_sessions(self, config, payload: Any, options=None):
         """
         Sends sessions to Bugsnag
         """
@@ -73,22 +72,35 @@ class Delivery:
                               'No sessions will be sent to Bugsnag.')
                 self.sent_session_warning = True
         else:
-            options = {
-                'endpoint': config.session_endpoint,
-                'success': 202,
-            }
+            if options is None:
+                options = {}
+
+            options['endpoint'] = config.session_endpoint
+            options['success'] = 202
+
             self.deliver(config, payload, options)
 
     def queue_request(self, request: Callable, config, options: Dict):
         if config.asynchronous and options.pop('asynchronous', True):
-            Thread(target=request).start()
+            # if an exception escapes the thread, our threading.excepthook
+            # will catch it and attempt to deliver it
+            # this will cause an infinite loop if delivery can never succeed,
+            # e.g. because the URL is unreachable
+            def safe_request():
+                try:
+                    request()
+                except Exception as e:
+                    config.logger.exception('Notifying Bugsnag failed %s', e)
+
+            Thread(target=safe_request).start()
         else:
             request()
 
 
 class UrllibDelivery(Delivery):
-
-    def deliver(self, config, payload: Any, options={}):
+    def deliver(self, config, payload: Any, options=None):
+        if options is None:
+            options = {}
 
         def request():
             uri = options.pop('endpoint', config.endpoint)
@@ -117,15 +129,17 @@ class UrllibDelivery(Delivery):
             else:
                 success = 200
             if status != success:
-                bugsnag.logger.warning(
-                    'Delivery to %s failed, status %d' % (uri, status))
+                config.logger.warning(
+                    'Delivery to %s failed, status %d' % (uri, status)
+                )
 
         self.queue_request(request, config, options)
 
 
 class RequestsDelivery(Delivery):
-
-    def deliver(self, config, payload: Any, options={}):
+    def deliver(self, config, payload: Any, options=None):
+        if options is None:
+            options = {}
 
         def request():
             uri = options.pop('endpoint', config.endpoint)
@@ -150,7 +164,8 @@ class RequestsDelivery(Delivery):
                 success = requests.codes.ok
 
             if status != success:
-                bugsnag.logger.warning(
-                    'Delivery to %s failed, status %d' % (uri, status))
+                config.logger.warning(
+                    'Delivery to %s failed, status %d' % (uri, status)
+                )
 
         self.queue_request(request, config, options)
